# tiledb-cloud
TileDB Storage Platform REST API

The `_common.api_v2` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.4.0
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.15
* six >= 1.10
* certifi
* python-dateutil

## Getting Started

In your own code, to use this library to connect and interact with tiledb-cloud,
you can run the following:

```python
from __future__ import print_function

import time
import tiledb.cloud._common.api_v2
from tiledb.cloud._common.api_v2.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = tiledb.cloud._common.api_v2.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKeyAuth
configuration = tiledb.cloud._common.api_v2.Configuration(
    host = "http://localhost",
    api_key = {
        'X-TILEDB-REST-API-KEY': 'YOUR_API_KEY'
    }
)
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-TILEDB-REST-API-KEY'] = 'Bearer'

# Configure HTTP basic authorization: BasicAuth
configuration = tiledb.cloud._common.api_v2.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)


# Enter a context with an instance of the API client
with tiledb.cloud._common.api_v2.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = tiledb.cloud._common.api_v2.ArrayApi(api_client)
    namespace = 'namespace_example' # str | namespace array is in (an organization name or user's username)
array = 'array_example' # str | name/uri of array that is url-encoded
start = 56 # int | Start time of window of fetch logs, unix epoch in seconds (default: seven days ago) (optional)
end = 56 # int | End time of window of fetch logs, unix epoch in seconds (default: current utc timestamp) (optional)
event_types = ['event_types_example'] # list[str] | Event values can be one or more of the following read, write, create, delete, register, deregister, comma separated (optional)
task_id = 'task_id_example' # str | Array task id To filter activity to (optional)
has_task_id = True # bool | Excludes activity log results that does not contain an array task uuid (optional)
page = 56 # int | pagination offset (optional)
per_page = 56 # int | pagination limit (optional)

    try:
        api_response = api_instance.array_activity_log(namespace, array, start=start, end=end, event_types=event_types, task_id=task_id, has_task_id=has_task_id, page=page, per_page=per_page)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ArrayApi->array_activity_log: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ArrayApi* | [**array_activity_log**](docs/ArrayApi.md#array_activity_log) | **GET** /v2/arrays/{namespace}/{array}/activity | 
*FilesApi* | [**handle_upload_file**](docs/FilesApi.md#handle_upload_file) | **POST** /v2/files/{namespace}/{array}/upload | 
*GroupsApi* | [**create_group**](docs/GroupsApi.md#create_group) | **POST** /v2/groups/{group_namespace} | 
*GroupsApi* | [**deregister_group**](docs/GroupsApi.md#deregister_group) | **DELETE** /v2/groups/{group_namespace}/{group_name} | 
*GroupsApi* | [**get_group_metadata**](docs/GroupsApi.md#get_group_metadata) | **POST** /v2/groups/{group_namespace}/{group_name}/metadata | 
*GroupsApi* | [**groups_group_namespace_group_name_options**](docs/GroupsApi.md#groups_group_namespace_group_name_options) | **OPTIONS** /v2/groups/{group_namespace}/{group_name} | 
*GroupsApi* | [**register_group**](docs/GroupsApi.md#register_group) | **PUT** /v2/groups/{group_namespace} | 
*GroupsApi* | [**retrieve_group**](docs/GroupsApi.md#retrieve_group) | **POST** /v2/groups/{group_namespace}/{group_name} | 
*GroupsApi* | [**update_group_contents**](docs/GroupsApi.md#update_group_contents) | **PATCH** /v2/groups/{group_namespace}/{group_name} | 
*GroupsApi* | [**update_group_metadata**](docs/GroupsApi.md#update_group_metadata) | **PUT** /v2/groups/{group_namespace}/{group_name}/metadata | 
*OrganizationApi* | [**add_credential**](docs/OrganizationApi.md#add_credential) | **POST** /v2/credentials/{namespace} | 
*OrganizationApi* | [**delete_credential**](docs/OrganizationApi.md#delete_credential) | **DELETE** /v2/credentials/{namespace}/{name} | 
*OrganizationApi* | [**get_credential**](docs/OrganizationApi.md#get_credential) | **GET** /v2/credentials/{namespace}/{name} | 
*OrganizationApi* | [**list_credentials**](docs/OrganizationApi.md#list_credentials) | **GET** /v2/credentials/{namespace} | 
*OrganizationApi* | [**update_credential**](docs/OrganizationApi.md#update_credential) | **PATCH** /v2/credentials/{namespace}/{name} | 
*QueryApi* | [**submit_query**](docs/QueryApi.md#submit_query) | **POST** /v2/arrays/{namespace}/{array}/query/submit | 
*UserApi* | [**add_credential**](docs/UserApi.md#add_credential) | **POST** /v2/credentials/{namespace} | 
*UserApi* | [**delete_credential**](docs/UserApi.md#delete_credential) | **DELETE** /v2/credentials/{namespace}/{name} | 
*UserApi* | [**get_credential**](docs/UserApi.md#get_credential) | **GET** /v2/credentials/{namespace}/{name} | 
*UserApi* | [**list_credentials**](docs/UserApi.md#list_credentials) | **GET** /v2/credentials/{namespace} | 
*UserApi* | [**update_credential**](docs/UserApi.md#update_credential) | **PATCH** /v2/credentials/{namespace}/{name} | 


## Documentation For Models

 - [AWSCredential](docs/AWSCredential.md)
 - [AWSRole](docs/AWSRole.md)
 - [AccessCredential](docs/AccessCredential.md)
 - [AccessCredentialCredential](docs/AccessCredentialCredential.md)
 - [AccessCredentialRole](docs/AccessCredentialRole.md)
 - [AccessCredentialsData](docs/AccessCredentialsData.md)
 - [ActivityEventType](docs/ActivityEventType.md)
 - [Array](docs/Array.md)
 - [ArrayActivityLog](docs/ArrayActivityLog.md)
 - [ArrayActivityLogData](docs/ArrayActivityLogData.md)
 - [AttributeBufferHeader](docs/AttributeBufferHeader.md)
 - [AttributeBufferSize](docs/AttributeBufferSize.md)
 - [AzureCredential](docs/AzureCredential.md)
 - [CloudProvider](docs/CloudProvider.md)
 - [Datatype](docs/Datatype.md)
 - [DomainArray](docs/DomainArray.md)
 - [Error](docs/Error.md)
 - [FileUploaded](docs/FileUploaded.md)
 - [GroupContentsChangesRequest](docs/GroupContentsChangesRequest.md)
 - [GroupContentsChangesRequestGroupChanges](docs/GroupContentsChangesRequestGroupChanges.md)
 - [GroupContentsRetrievalRequest](docs/GroupContentsRetrievalRequest.md)
 - [GroupContentsRetrievalResponse](docs/GroupContentsRetrievalResponse.md)
 - [GroupCreationRequest](docs/GroupCreationRequest.md)
 - [GroupCreationRequestGroupDetails](docs/GroupCreationRequestGroupDetails.md)
 - [GroupMember](docs/GroupMember.md)
 - [GroupMemberAssetType](docs/GroupMemberAssetType.md)
 - [GroupMemberType](docs/GroupMemberType.md)
 - [GroupMetadataRetrievalRequest](docs/GroupMetadataRetrievalRequest.md)
 - [GroupMetadataUpdateRequest](docs/GroupMetadataUpdateRequest.md)
 - [GroupRegistrationRequest](docs/GroupRegistrationRequest.md)
 - [GroupRegistrationRequestGroupDetails](docs/GroupRegistrationRequestGroupDetails.md)
 - [Layout](docs/Layout.md)
 - [Metadata](docs/Metadata.md)
 - [MetadataEntry](docs/MetadataEntry.md)
 - [PaginationMetadata](docs/PaginationMetadata.md)
 - [Query](docs/Query.md)
 - [QueryReader](docs/QueryReader.md)
 - [Querystatus](docs/Querystatus.md)
 - [Querytype](docs/Querytype.md)
 - [ReadState](docs/ReadState.md)
 - [Subarray](docs/Subarray.md)
 - [SubarrayPartitioner](docs/SubarrayPartitioner.md)
 - [SubarrayPartitionerCurrent](docs/SubarrayPartitionerCurrent.md)
 - [SubarrayPartitionerState](docs/SubarrayPartitionerState.md)
 - [SubarrayRanges](docs/SubarrayRanges.md)
 - [TileDBConfig](docs/TileDBConfig.md)
 - [TileDBConfigEntries](docs/TileDBConfigEntries.md)
 - [Writer](docs/Writer.md)


## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-TILEDB-REST-API-KEY
- **Location**: HTTP header


## BasicAuth

- **Type**: HTTP basic authentication


## OAuth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://oauth2.tiledb.com/oauth2/authorize
- **Scopes**: 
 - **read**: Grants read access
 - **write**: Grants write access
 - **admin**: Grants read and write access to administrative information


## Author




